## Code compatibility problems

The tables below assist with verifying if workflows and dashboards are Unity Catalog compatible. It can be filtered on the path,
problem code and workflow name.
Each row:
- Points to a problem detected in the code using the code path, query or workflow & task reference and start/end line & column;
- Explains the problem with a human-readable message and a code.

